@@ -6,6 +6,8 @@ import (
 	"encoding/binary"
 	"fmt"
 	"io"
+	"net"
+	"strings"
 	"time"
 
 	"github.com/miekg/dns"
@@ -19,12 +21,35 @@ type DOQResolver struct {
 	resolverOptions Options
 }
 
+// splitHostPort splits a host:port string and handles IPv6 addresses properly.
+// Returns the host without port and brackets.
+func splitHostPort(addr string) (host, port string, err error) {
+	host, port, err = net.SplitHostPort(addr)
+	if err != nil {
+		return "", "", err
+	}
+	// Remove brackets from IPv6 addresses
+	host = strings.Trim(host, "[]")
+	return host, port, nil
+}
+
 // NewDOQResolver accepts a nameserver address and configures a DOQ based resolver.
 func NewDOQResolver(server string, resolverOpts Options) (Resolver, error) {
+	// Extract hostname from server address for TLS verification
+	// If TLSHostname is explicitly set via flag, use that; otherwise extract from server address
+	tlsHostname := resolverOpts.TLSHostname
+	if tlsHostname == "" {
+		// server is in format "hostname:port", extract just the hostname
+		host, _, err := splitHostPort(server)
+		if err == nil {
+			tlsHostname = host
+		}
+	}
+
 	return &DOQResolver{
 		tls: &tls.Config{
 			NextProtos:         []string{"doq"},
-			ServerName:         resolverOpts.TLSHostname,
+			ServerName:         tlsHostname,
 			InsecureSkipVerify: resolverOpts.InsecureSkipVerify,
 		},
 		server:          server,
@@ -72,7 +97,6 @@ func (r *DOQResolver) query(ctx context.Context, question dns.Question, flags Qu
 		if err != nil {
 			return rsp, err
 		}
-		defer stream.Close()
 
 		msgLen := uint16(len(b))
 		msgLenBytes := []byte{byte(msgLen >> 8), byte(msgLen & 0xFF)}
@@ -84,6 +108,16 @@ func (r *DOQResolver) query(ctx context.Context, question dns.Question, flags Qu
 			return rsp, err
 		}
 
+		// The client MUST send the DNS query over the selected stream, and MUST
+		// indicate through the STREAM FIN mechanism that no further data will be
+		// sent on that stream. Note, that stream.Close() closes the write-direction
+		// of the stream, but does not prevent reading from it.
+		// See: https://github.com/AdguardTeam/dnsproxy/blob/f901a5f4b9e8d5f143dce459067bc6614c6d927d/upstream/doq.go#L247-L254
+		err = stream.Close()
+		if err != nil {
+			return rsp, fmt.Errorf("unable to close quic stream: %w", err)
+		}
+
 		// Use a separate context with timeout for reading the response
 		readCtx, cancel := context.WithTimeout(ctx, r.resolverOptions.Timeout)
 		defer cancel()
@@ -107,6 +141,10 @@ func (r *DOQResolver) query(ctx context.Context, question dns.Question, flags Qu
 
 		rtt := time.Since(now)
 
+		if len(buf) < 2 {
+			return rsp, fmt.Errorf("response too short: got %d bytes, need at least 2", len(buf))
+		}
+
 		packetLen := binary.BigEndian.Uint16(buf[:2])
 		if packetLen != uint16(len(buf[2:])) {
 			return rsp, fmt.Errorf("packet length mismatch")
@@ -127,6 +165,8 @@ func (r *DOQResolver) query(ctx context.Context, question dns.Question, flags Qu
 		output := parseMessage(&msg, rtt, r.server)
 		rsp.Authorities = output.Authorities
 		rsp.Answers = output.Answers
+		rsp.Additional = output.Additional
+		rsp.Edns = output.Edns
 
 		if len(output.Answers) > 0 {
 			// stop iterating the searchlist.
